@@ -2,9 +2,11 @@
 """
 from datetime import datetime
 
+from sqlalchemy import select
 from sqlalchemy.orm import Mapped, mapped_column
 
 from hdx.database.no_timezone import Base
+from hdx.database.views import view
 
 
 class DBTestDate(Base):
@@ -21,3 +23,10 @@ class DBTestDate(Base):
             str: String representation of DBTestDate row
         """
         return f"<Test date={str(self.test_date)}>"
+
+
+date_view = view(
+    name="date_view",
+    metadata=Base.metadata,
+    selectable=select(*DBTestDate.__table__.columns),
+)
